@@ -121,7 +121,9 @@ class Feed2Imap
             end
             fetch_start = Time::now
             if feed.url
-              s = HTTPFetcher::fetch(feed.url, @cache.get_last_check(feed.name))
+              fetcher = HTTPFetcher::new
+              fetcher::timeout = @config.timeout
+              s = fetcher::fetch(feed.url, @cache.get_last_check(feed.name))
             elsif feed.execurl
               # avoid running more than one command at the same time.
               # We need it because the called command might not be
@@ -221,7 +223,7 @@ class Feed2Imap
         next
       end
       begin
-        feed = FeedParser::Feed::new(f.body)
+        feed = FeedParser::Feed::new(f.body.force_encoding('UTF-8'), f.url)
       rescue Exception
         n = @cache.parse_failed(f.name)
         m = "Error while parsing #{f.name}: #{$!} (failed #{n} times)"
@@ -247,7 +249,7 @@ class Feed2Imap
             id = "<#{fn}-#{i.cacheditem.index}@#{@config.hostname}>"
             email = item_to_mail(@config, i, id, true, f.name, f.include_images, f.wrapto)
             f.imapaccount.updatemail(f.folder, email,
-                                     id, i.date || Time::new)
+                                     id, i.date || Time::new, f.reupload_if_updated)
           end
           # reverse is needed to upload older items first (fixes gna#8986)
           newitems.reverse.each do |i|
