@@ -18,7 +18,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 =end
 
 # Imap connection handling
-require 'feed2imap/rubyimap'
+require 'net/imap'
 begin
 require 'openssl'
 rescue LoadError
@@ -108,7 +108,7 @@ class ImapAccount
   end
 
   # update a mail
-  def updatemail(folder, mail, id, date = Time::now)
+  def updatemail(folder, mail, id, date = Time::now, reupload_if_updated = true)
     create_folder_if_not_exists(folder)
     @connection.select(folder)
     searchres = @connection.search(['HEADER', 'Message-Id', id])
@@ -119,6 +119,9 @@ class ImapAccount
       searchres.each { |m| @connection.store(m, "+FLAGS", [:Deleted]) }
       @connection.expunge
       flags -= [ :Recent ] # avoids errors with dovecot
+    elsif not reupload_if_updated
+      # mail not present, and we don't want to re-upload it
+      return
     end
     @connection.append(folder, mail.gsub(/\n/, "\r\n"), flags, date)
   end
@@ -141,7 +144,9 @@ class ImapAccount
       d = f[0].attr['INTERNALDATE']
       s = f[0].attr['ENVELOPE'].subject
       if s =~ /^=\?utf-8\?b\?/
-        s = Base64::decode64(s.gsub(/^=\?utf-8\?b\?(.*)\?=$/, '\1')).toISO_8859_1('utf-8')
+        s = Base64::decode64(s.gsub(/^=\?utf-8\?b\?(.*)\?=$/, '\1')).force_encoding('utf-8')
+      elsif s =~ /^=\?iso-8859-1\?b\?/
+        s = Base64::decode64(s.gsub(/^=\?iso-8859-1\?b\?(.*)\?=$/, '\1')).force_encoding('iso-8859-1').encode('utf-8')
       end
       if dryrun
         puts "To remove: #{s} (#{d})"
